@@ -3,12 +3,17 @@ print('Stop using this module, use six for ConfigParser and '
 
 from logging.handlers import SysLogHandler
 
-__all__ = ['configparser', 'UTFFixedSysLogHandler']
+__all__ = ['configparser', 'UTFFixedSysLogHandler', 'json']
 
 try:
     import ConfigParser as configparser
 except ImportError:
     import configparser
 
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
 
 UTFFixedSysLogHandler = SysLogHandler
